//
//  SITOrganizationTheme.h
//  SitumSDK
//
//  Created by Situm on 11/12/2020.
//  Copyright © 2020 Situm. All rights reserved.
//

#import "SITResource.h"
#import "SITThemeColors.h"
#import "SITURL.h"

NS_ASSUME_NONNULL_BEGIN
/**
 Class to represents different parameters to adapt the look and feel of an organization.
 To get all these parameters you must have selected the Tracking Package (https://dashboard.situm.es/accounts/register)
 */
/// - Tag: SITOrganizationTheme
@interface SITOrganizationTheme : SITResource

/**
 Relative url where the logo of the organization can be found
 */
@property (nonatomic, readonly) SITURL *logo;

/**
 Name of the organization
 */
@property (nonatomic, readonly) NSString *organizationName;

/**
 Identifier of the organization
 */
@property (nonatomic, readonly) NSString *organizationUuid;

/**
 @link SITThemeColors object
 */
@property (nonatomic, readonly) SITThemeColors *themeColors;

/**
 Initializer of the class
 As a developer you should not create instances of this class. Instead you should use the ones provided by {@link SITCommunicationManager#fetchOrganicationThemeWithOptions:success:failure}
 /// Make sure to get your instances from [fetchOrganization](x-source-tag://fetchOrganization) instead of creating them.
 */
- (instancetype)initWithIdentifier:(NSString *)identifier
                         createdAt:(NSDate *)createdAt
                         updatedAt:(NSDate *)updatedAt
                      customFields:(NSDictionary *)customFields
                  organizationName:(NSString *)organizationName
                  organizationUuid:(NSString *)organizationUuid
                       themeColors:(SITThemeColors *)themeColors
                              logo:(SITURL *)logo;

@end

NS_ASSUME_NONNULL_END
